@@ -31,7 +31,7 @@ use Data::FormValidator::Constraints (qw/:validators :matchers/);
 
 use vars qw( $VERSION $AUTOLOAD @ISA @EXPORT_OK %EXPORT_TAGS );
 
-$VERSION = '3.14';
+$VERSION = '3.15';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -125,7 +125,7 @@ Data::FormValidator's main aim is to make input validation expressible in a
 simple format.
 
 Data::FormValidator lets you define profiles which declare the
-required  and optional fields and any constraints they might have.
+required and optional fields and any constraints they might have.
 
 The results are provided as an object which makes it easy to handle 
 missing and invalid results, return error messages about which constraints
@@ -170,9 +170,9 @@ sub new {
 
  my $results = Data::FormValidator->check(\%input_hash, \%dfv_profile);
 
-C<check> is the recommended method to use to validate forms. It returns it's results as
+C<check> is the recommended method to use to validate forms. It returns it's results as a
 L<Data::FormValidator::Results|Data::FormValidator::Results> object.  A
-deprecated method C<validate> is also available, returning it's results in
+deprecated method C<validate> is also available, returning it's results as an
 array described below.
 
  use Data::FormValidator;
@@ -181,9 +181,10 @@ array described below.
 Here, C<check()> is used as a class method, and takes two required parameters. 
 
 The first a reference to the data to be be validated. This can either be a hash
-reference, or a CGI or Apache::Request object.  Note that if you use a hash
-reference, multiple values for a single key should be presented as an array
-reference.
+reference, or a CGI.pm-like object. In particular, the object must have a param()
+method that works like the one in CGI.pm does. CGI::Simple and Apache::Request
+objects are known to work in particular. Note that if you use a hash reference,
+multiple values for a single key should be presented as an array reference.
 
 The second argument is a reference to the profile you are validating.
 
@@ -206,7 +207,7 @@ the data. The data may have been modified by the various filters specified.
 
 This is a reference to an array which contains the name of the missing
 fields. Those are the fields that the user forget to fill or filled
-with space. These fields may comes from the I<required> list or the
+with spaces. These fields may comes from the I<required> list or the
 I<dependencies> list.
 
 =item invalids
@@ -278,14 +279,14 @@ validation profile will completely overwrite your default value.
 This means you can't define two keys for C<constraint_regexp_map> and expect
 they will always be there. This kind of feature may be added in the future.
 
-The exception here is are definitions for your C<msgs> key. You will safely  
+The exception here is definitions for your C<msgs> key. You will safely  
 be able to define some defaults for this key and not have them entirely clobbered 
 just because C<msgs> was defined in a validation profile.
 
 One way to use this feature is to create your own sub-class that always provides
 your defaults to C<new()>. 
 
-Another option to create your own wrapper routine which provides these defaults to 
+Another option is to create your own wrapper routine which provides these defaults to 
 C<new()>.  Here's an example of a routine you might put in a
 L<CGI::Application|CGI::Application> super-class to make use of this feature:
 
@@ -393,31 +394,30 @@ examples of each.
 =head2 required
 
 This is an array reference which contains the name of the fields which are
-required. Any fields in this list which are not present, or contain only
-spaces.  will be reported as missing.
-
+required. Any fields in this list which are not present or contain only
+spaces will be reported as missing.
 
 =head2 required_regexp
 
  required_regexp => qr/city|state|zipcode/,
 
-This is a regular expression used to specify additional fieds which are
+This is a regular expression used to specify additional fields which are
 required.
 
+=head2 require_some
+
  require_some => {
     # require any two fields from this group
     city_or_state_or_zipcode => [ 2, qw/city state zipcode/ ], 
  }
 
-This is a reference to a hash which defines groups of fields where 
-1 or more field from the group should be required, but exactly
-which fields doesn't matter. The keys in the hash are the group names. 
-These are returned as "missing" unless the required number of fields
-from the group has been filled in. The values in this hash are
-array references. The first element in this hash should be the 
-number of fields in the group that is required. If the first
-first field in the array is not an a digit, a default of "1" 
-will be used. 
+This is a reference to a hash which defines groups of fields where 1 or more
+fields from the group should be required, but exactly which fields doesn't
+matter. The keys in the hash are the group names.  These are returned as
+"missing" unless the required number of fields from the group has been filled
+in. The values in this hash are array references. The first element in this
+array should be the number of fields in the group that is required. If the
+first field in the array is not an a digit, a default of "1" will be used. 
 
 =head2 optional
 
@@ -425,14 +425,14 @@ will be used.
 
 This is an array reference which contains the name of optional fields.
 These are fields which MAY be present and if they are, they will be
-check for valid input. Any fields not in optional or required list
+checked for valid input. Any fields not in optional or required list
 will be reported as unknown.
 
 =head2 optional_regexp
 
  optional_regexp => qr/_province$/,
 
-This is a regular expression used to specify additional fieds which are
+This is a regular expression used to specify additional fields which are
 optional. For example, if you wanted all fields names that begin with I<user_> 
 to be optional, you could use the regular expression, /^user_/
 
@@ -479,7 +479,7 @@ the values are references to arrays of the field names in each group.
  },
 
 This is a hash reference where keys are field names and 
-values are defaults to use if input for th e field is missing. 
+values are defaults to use if input for the field is missing. 
 
 The defaults are set shortly before the constraints are applied, and
 will be returned with the other valid data.
@@ -504,7 +504,7 @@ See Data::FormValidator::Filters for details on the built-in filters.
 =head2 field_filters
 
  field_filters => { 
- 	cc_no => "digit"
+ 	cc_no => ['digit'],
  },
 
 A hash ref with field names and keys. Values are array references
@@ -516,7 +516,7 @@ See Data::FormValidator::Filters for details on the built-in filters.
 
  field_filter_regexp_map => {
  	# Upper-case the first letter of all fields that end in "_name"
- 	qr/_name$/	=> 'ucfirst',
+ 	qr/_name$/	=> ['ucfirst'],
  },
 
 This is a hash reference where the keys are the regular expressions to
@@ -538,7 +538,7 @@ match a regular expression.
 A hash ref which contains the constraints that
 will be used to check whether or not the field contains valid data.
 
-The keys in this hash are field names. The values can any of the following:
+The keys in this hash are field names. The values can be any of the following:
 
 =over 
 
@@ -602,11 +602,11 @@ a hash reference, to name a constraint or supply multiple parameters.
  },
 
 Using the hash reference for a constraint allows the possibility to
-pass in multiple arguments to the constraintk, and to provide a name for for a
+pass in multiple arguments to the constraint, and to provide a name for a
 constraint that doesn't have one. The name can be used in the error message
 system to return a custom error message for this constraint. In some cases you
 will want to use C<constraint_method> instead of C<constraint>.  Consult the
-documentation for the the constraint you are using to see which is correct for
+documentation for the constraint you are using to see which is correct for
 that case.  If in doubt, use C<constraint>.
 
 For details see L<VALIDATING INPUT BASED ON MULTIPLE FIELDS>.
@@ -639,7 +639,7 @@ field for each regular expression that matches.
 
  untaint_all_constraints => 1,
 
-If this field is set all form data that passes a constraint will be untainted.
+If this field is set, all form data that passes a constraint will be untainted.
 The untainted data will be returned in the valid hash.  Untainting is based on
 the pattern match used by the constraint.  Note that some constraint routines
 may not provide untainting.
@@ -657,7 +657,7 @@ Specifies that one or more fields will be untainted if they pass their
 constraint(s). This can be set to a single field name or an array reference of
 field names. The untainted data will be returned in the valid hash. 
 
-This is overrides the untaint_all_constraints flag.
+This overrides the untaint_all_constraints flag.
 
 =head2 missing_optional_valid
 
@@ -738,7 +738,7 @@ as providing custom messages per field, and handling multiple constraints:
                      # ...
      },
  
- 	# This token will be included in the hash if they are 
+ 	# This token will be included in the hash if there are 
  	# any errors returned. This can be useful with templating
  	# systems like HTML::Template
  	# The 'prefix' setting does not apply here.
@@ -793,8 +793,8 @@ Using the original syntax, one key should be named C<constraint> and should
 have a value set to the reference of the subroutine or the name of a built-in
 validator.  Another required key is I<params>. The value of the I<params> key
 is a reference to an array of the other elements to use in the validation. If
-the element is a scalar, it is assumed to a field name. If the value is a
-reference, The reference is passed directly to the routine. Don't forget to
+the element is a scalar, it is assumed to be a field name. If the value is a
+reference, the reference is passed directly to the routine. Don't forget to
 include the name of the field to check in that list, if you are using this syntax.
 
 B<Example>:
@@ -917,7 +917,7 @@ L<Data::FormValidator::Results|Data::FormValidator::Results>
 
 B<A sample application by the maintainer:> 
 
-Validationg Web Forms with Perl, L<http://mark.stosberg.com/Tech/perl/form-validation/>
+Validating Web Forms with Perl, L<http://mark.stosberg.com/Tech/perl/form-validation/>
 
 B<Related modules:>
 
@@ -926,7 +926,7 @@ L<Data::FormValidator::Tutorial|Data::FormValidator::Tutorial>
 L<CGI::Application::ValidateRM|CGI::Application::ValidateRM>, a
 CGI::Application & Data::FormValidator glue module
 
-L<Params::Validate |Params::Validate> looks like a better choice for validating function parameters.  
+L<Params::Validate|Params::Validate> looks like a better choice for validating function parameters.  
 
 L<Regexp::Common|Regexp::Common>,
 L<Data::Types|Data::Types>,
@@ -937,12 +937,15 @@ L<CGI::ArgChecker|CGI::ArgChecker>,
 L<CGI::FormMagick::Validator|CGI::FormMagick::Validator>,
 L<CGI::Validate|CGI::Validate>
 
-
-
 B<Document Translations:>
 
 Japanese: L<http://perldoc.jp/docs/modules/>
 
+B<Distributions which include Data::formValidator> 
+
+FreeBSD includes a port named B<p5-Data-FormValidator>
+Debian GNU/Linux includes a port named B<libdata-formvalidator-perl>
+
 =head1 CREDITS
 
 Some of those input validation functions have been taken from MiniVend
